"use client";

import { useState, useEffect, useCallback, useMemo } from "react";
import { useRouter, useSearchParams } from "next/navigation";
import { format, startOfWeek, endOfWeek, eachDayOfInterval, addDays, isSaturday, parseISO } from "date-fns";
import { CalendarCheck, ChevronLeft, ChevronRight, CalendarDays, User, Info, Loader2 } from "lucide-react";
import { useAuth } from "@/lib/hooks/useAuth";
import { useClasses } from "@/lib/hooks/useClasses";
import { useAttendance } from "@/lib/hooks/useAttendance";
import { useStudents } from "@/lib/hooks/useStudents";
import DashboardLayout from "@/components/layout/DashboardLayout";
import { AttendanceForm } from "@/components/attendance/AttendanceForm";
import { ChartContainer } from "@/components/dashboard/ChartContainer";
import { Button } from "@/components/ui/button";
import { Calendar } from "@/components/ui/calendar";
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card";
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import { Skeleton } from "@/components/ui/skeleton";
import { Table, TableHeader, TableRow, TableHead, TableBody, TableCell } from "@/components/ui/table";
import { Tooltip, TooltipContent, TooltipProvider, TooltipTrigger } from "@/components/ui/tooltip";
import { Attendance, Student } from "@/lib/types";

function isWeekend(date: Date) {
  const day = date.getDay();
  return day === 0 || day === 6;
}

function getNextSaturday() {
  const today = new Date();
  const result = new Date(today);
  result.setDate(today.getDate() + (6 - today.getDay()));
  return result;
}

function getNextWeekday() {
  const today = new Date();
  const result = new Date(today);
  if (isWeekend(today)) {
    const daysUntilMonday = (8 - today.getDay()) % 7;
    result.setDate(today.getDate() + daysUntilMonday);
  }
  return result;
}

export default function AttendancePage() {
  const router = useRouter();
  const searchParams = useSearchParams();
  const { user, loading: authLoading } = useAuth();
  const { classes, loading: classesLoading } = useClasses();
  const { getAttendanceByStudent, getAttendanceByClass } = useAttendance();
  const { students, loading: studentsLoading } = useStudents();
  
  const studentId = searchParams.get("studentId");
  const [isWeekdayView, setIsWeekdayView] = useState(true);
  
  // State management
  const [selectedDate, setSelectedDate] = useState<Date>(new Date());
  const [selectedClass, setSelectedClass] = useState<string>("");
  const [activeTab, setActiveTab] = useState("mark");
  const [studentAttendance, setStudentAttendance] = useState<Attendance[]>([]);
  const [weeklyAttendance, setWeeklyAttendance] = useState<any[]>([]);
  const [selectedStudent, setSelectedStudent] = useState<Student | null>(null);
  const [isLoading, setIsLoading] = useState(false);
  const [error, setError] = useState<string | null>(null);

  // Memoize the next appropriate date based on view
  const initialDate = useMemo(() => {
    return isWeekdayView ? getNextWeekday() : getNextSaturday();
  }, [isWeekdayView]);

  // Initialize date based on current view
  useEffect(() => {
    setSelectedDate(initialDate);
  }, [initialDate]);

  // Redirect if not authenticated or not admin/teacher
  useEffect(() => {
    if (!authLoading && (!user || (user.role !== "admin" && user.role !== "teacher"))) {
      router.push("/auth");
    }
  }, [user, authLoading, router]);

  // Set initial selected class
  useEffect(() => {
    if (!classesLoading && classes.length > 0 && !selectedClass) {
      setSelectedClass(classes[0].id);
    }
  }, [classes, classesLoading, selectedClass]);

  // Get students for the selected class
  const classStudents = useMemo(() => {
    return students.filter(student => 
      student.classIds?.includes(selectedClass)
    );
  }, [students, selectedClass]);

  // Fetch student attendance if studentId is provided
  useEffect(() => {
    if (studentId && students.length > 0) {
      const student = students.find(s => s.id === studentId);
      if (student) {
        setSelectedStudent(student);
        fetchStudentAttendance(studentId);
        setActiveTab("view");
      }
    }
  }, [studentId, students]);

  const fetchStudentAttendance = useCallback(async (studentId: string) => {
  try {
    setIsLoading(true);
    setError(null);
    
    const today = new Date();
    const oneMonthAgo = new Date();
    oneMonthAgo.setMonth(today.getMonth() - 1);
    
    const startDate = format(oneMonthAgo, "yyyy-MM-dd");
    const endDate = format(today, "yyyy-MM-dd");
    
    const attendance = await getAttendanceByStudent(studentId, startDate, endDate);
    setStudentAttendance(attendance);
  } catch (error) {
    console.error("Error fetching student attendance:", error);
    setError("Failed to load attendance data");
    setStudentAttendance([]); // Reset to empty array on error
  } finally {
    setIsLoading(false);
  }
}, [getAttendanceByStudent]);

  // Fetch weekly attendance data for selected class
  const fetchWeeklyAttendance = useCallback(async (classId: string) => {
    try {
      setIsLoading(true);
      setError(null);
      
      let startDate: Date;
      let endDate: Date;
      
      if (isWeekdayView) {
        // Get current week (Monday-Friday)
        const today = new Date();
        const startOfWeekDate = startOfWeek(today, { weekStartsOn: 1 });
        endDate = addDays(startOfWeekDate, 4);
        startDate = startOfWeekDate;
      } else {
        // Get all Saturdays in current month
        const saturdays = getSaturdaysInMonth();
        startDate = saturdays[0];
        endDate = saturdays[saturdays.length - 1];
      }
      
      const formattedStart = format(startDate, "yyyy-MM-dd");
      const formattedEnd = format(endDate, "yyyy-MM-dd");
      
      const attendanceRecords = await getAttendanceByClass(classId, formattedStart, formattedEnd);
      
      if (!attendanceRecords) {
        throw new Error("No attendance records returned");
      }
      
      const weeklyData = processAttendanceData(attendanceRecords, isWeekdayView);
      setWeeklyAttendance(weeklyData);
    } catch (error) {
      console.error("Error fetching weekly attendance:", error);
      setError("Failed to fetch weekly attendance");
      setWeeklyAttendance([]);
    } finally {
      setIsLoading(false);
    }
  }, [getAttendanceByClass, isWeekdayView]);

  const processAttendanceData = (records: Attendance[], isWeekday: boolean) => {
  const dayData: Record<string, { present: number; absent: number; late: number }> = {};
  
  records.forEach(record => {
    const date = typeof record.date === 'string' ? parseISO(record.date) : record.date;
    const dayName = format(date, isWeekday ? 'EEE' : 'EEE, MMM d');
    
    if (!dayData[dayName]) {
      dayData[dayName] = { present: 0, absent: 0, late: 0 };
    }
    
    if (record.status === 'present') dayData[dayName].present++;
    else if (record.status === 'absent') dayData[dayName].absent++;
    else if (record.status === 'late') dayData[dayName].late++;
  });
  
  const expectedDays = isWeekday 
    ? ['Mon', 'Tue', 'Wed', 'Thu', 'Fri']
    : ['Sat']; // Or format specific dates for Saturdays
  
  return expectedDays.map(day => ({
    name: day,
    present: dayData[day]?.present || 0,
    absent: dayData[day]?.absent || 0,
    late: dayData[day]?.late || 0
  }));
};

  // Get all Saturdays in the current month
  const getSaturdaysInMonth = useCallback(() => {
    const today = new Date();
    const year = today.getFullYear();
    const month = today.getMonth();
    
    const firstDay = new Date(year, month, 1);
    const lastDay = new Date(year, month + 1, 0);
    
    const saturdays: Date[] = [];
    const interval = eachDayOfInterval({ start: firstDay, end: lastDay });
    
    interval.forEach(day => {
      if (isSaturday(day)) {
        saturdays.push(day);
      }
    });
    
    return saturdays.length > 0 ? saturdays : [getNextSaturday()];
  }, []);

  useEffect(() => {
    if (selectedClass) {
      fetchWeeklyAttendance(selectedClass);
    }
  }, [selectedClass, fetchWeeklyAttendance]);

  const handlePreviousDay = () => {
    const prevDay = new Date(selectedDate);
    prevDay.setDate(prevDay.getDate() - (isWeekdayView ? 1 : 7));
    
    if (isWeekdayView) {
      while (isWeekend(prevDay)) {
        prevDay.setDate(prevDay.getDate() - 1);
      }
    }
    
    setSelectedDate(prevDay);
  };

  const handleNextDay = () => {
    const nextDay = new Date(selectedDate);
    nextDay.setDate(nextDay.getDate() + (isWeekdayView ? 1 : 7));
    
    if (isWeekdayView) {
      while (isWeekend(nextDay)) {
        nextDay.setDate(nextDay.getDate() + 1);
      }
    }
    
    setSelectedDate(nextDay);
  };

  const calculateStats = useCallback(() => {
    if (!studentAttendance.length) return { present: 0, absent: 0, late: 0 };
    
    return studentAttendance.reduce((acc, record) => {
      acc[record.status]++;
      return acc;
    }, { present: 0, absent: 0, late: 0 });
  }, [studentAttendance]);

  const studentStats = calculateStats();

  const StatusBadge = ({ status, remarks }: { status: string; remarks?: string }) => {
    const baseClasses = "inline-flex items-center rounded-full px-2.5 py-0.5 text-xs font-medium";
    
    const statusClasses = {
      present: "bg-green-100 text-green-800 dark:bg-green-900 dark:text-green-300",
      absent: "bg-red-100 text-red-800 dark:bg-red-900 dark:text-red-300",
      late: "bg-yellow-100 text-yellow-800 dark:bg-yellow-900 dark:text-yellow-300"
    } as const;
  
    const statusKey = status as keyof typeof statusClasses;
    const statusClass = statusClasses[statusKey] || "bg-gray-100 text-gray-800";

  
    return (
      <div className="flex items-center gap-1">
        <span className={`${baseClasses} ${statusClass}`}>
          {status.charAt(0).toUpperCase() + status.slice(1)}
        </span>
        {status === "absent" && remarks && (
          <Tooltip>
            <TooltipTrigger>
              <Info className="h-3 w-3 text-muted-foreground" />
            </TooltipTrigger>
            <TooltipContent>
              <p className="font-medium">Absence Reason:</p>
              <p>{remarks}</p>
            </TooltipContent>
          </Tooltip>
        )}
      </div>
    );
  };

  const StatCard = ({ value, label, variant }: { value: number; label: string; variant: "success" | "destructive" | "warning" }) => {
    const colorClasses = {
      success: "text-green-600 dark:text-green-400",
      destructive: "text-red-600 dark:text-red-400",
      warning: "text-yellow-600 dark:text-yellow-400"
    };
  
    return (
      <Card>
        <CardContent className="pt-6">
          <div className="text-center">
            <div className={`text-2xl font-bold ${colorClasses[variant]}`}>
              {value}
            </div>
            <div className="text-sm font-medium text-muted-foreground">
              {label}
            </div>
          </div>
        </CardContent>
      </Card>
    );
  };

  const isLoaded = !authLoading && !classesLoading && classes.length > 0 && !studentsLoading;

  return (
    <DashboardLayout>
      <div className="space-y-6">
        <div className="flex justify-between items-start">
          <div>
            <h1 className="text-3xl font-bold tracking-tight">
              {isWeekdayView ? 'Weekday' : 'Saturday'} Attendance
            </h1>
            <p className="text-muted-foreground">
              Track and manage student attendance records {isWeekdayView ? 'from Monday to Friday' : 'for Saturdays'}
            </p>
          </div>
          
          <Button  
            onClick={() => setIsWeekdayView(!isWeekdayView)}
            className="flex items-center gap-2"
          >
            <CalendarDays className="h-4 w-4" />
            {isWeekdayView ? 'View Saturday Attendance' : 'View Weekday Attendance'}
          </Button>
        </div>

        {error && (
          <div className="bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded relative">
            {error}
          </div>
        )}

        <Tabs value={activeTab} onValueChange={setActiveTab}>
          <TabsList className="grid w-full grid-cols-2 lg:w-[400px]">
            <TabsTrigger value="mark">Mark Attendance</TabsTrigger>
            <TabsTrigger value="view">View & Reports</TabsTrigger>
          </TabsList>
          
          <TabsContent value="mark" className="space-y-6">
            <Card>
              <CardHeader>
                <CardTitle>Mark {isWeekdayView ? 'Weekday' : 'Saturday'} Attendance</CardTitle>
                <CardDescription>
                  Record attendance for a class on {isWeekdayView ? 'weekdays (Monday to Friday)' : 'Saturdays'}
                </CardDescription>
              </CardHeader>
              <CardContent className="space-y-6">
                <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                  <div className="space-y-4">
                    <div>
                      <label className="block text-sm font-medium mb-2">Select Class</label>
                      {classesLoading ? (
                        <Skeleton className="h-10 w-full" />
                      ) : (
                        <Select
                          value={selectedClass}
                          onValueChange={(value) => {
                            setSelectedClass(value);
                            setSelectedDate(isWeekdayView ? getNextWeekday() : getNextSaturday());
                          }}
                          disabled={classesLoading || classes.length === 0}
                        >
                          <SelectTrigger className="w-full [&>svg]:transition-transform [&[data-state=open]>svg]:rotate-180">
                            <SelectValue placeholder={classesLoading ? "Loading classes..." : "Select a class"} />
                          </SelectTrigger>
                          <SelectContent>
                            {classes.map((cls) => (
                              <SelectItem key={cls.id} value={cls.id}>
                                {cls.level ? `${cls.name} (${cls.level})` : cls.name}
                              </SelectItem>
                            ))}
                          </SelectContent>
                        </Select>
                      )}
                    </div>
                    
                    <div>
                      <label className="block text-sm font-medium mb-2">Select Date</label>
                      <div className="flex items-center space-x-2">
                        <Button
                          variant="outline"
                          size="icon"
                          onClick={handlePreviousDay}
                          disabled={!selectedClass}
                        >
                          <ChevronLeft className="h-4 w-4" />
                        </Button>
                        <div className="flex-1 text-center border rounded-md py-2 px-4">
                          {format(selectedDate, "EEEE, MMMM d, yyyy")}
                        </div>
                        <Button
                          variant="outline"
                          size="icon"
                          onClick={handleNextDay}
                          disabled={!selectedClass}
                        >
                          <ChevronRight className="h-4 w-4" />
                        </Button>
                      </div>
                    </div>
                  </div>
                  
                  <div className="flex justify-center">
                    <Calendar
                      mode="single"
                      selected={selectedDate}
                      onSelect={(date) => {
                        if (date && (isWeekdayView ? !isWeekend(date) : isSaturday(date))) {
                          setSelectedDate(date);
                        }
                      }}
                      className="rounded-md border"
                      modifiers={{
                        weekend: { dayOfWeek: [0, 6] },
                        saturday: { dayOfWeek: [6] }
                      }}
                      modifiersStyles={{
                        weekend: {
                          color: '#ef4444',
                          textDecoration: 'line-through',
                          opacity: 0.5
                        },
                        saturday: isWeekdayView ? {} : {
                          fontWeight: 'bold',
                          color: '#3b82f6',
                          opacity: 1,
                          textDecoration: 'none',
                        }
                      }}
                      disabled={(date) => isWeekdayView ? isWeekend(date) : !isSaturday(date)}
                    />
                  </div>
                </div>
                
                {selectedClass ? (
                  classStudents.length > 0 ? (
                    <AttendanceForm 
                      classId={selectedClass} 
                      className={classes.find(c => c.id === selectedClass)?.name || ""}
                      classLevel={classes.find(c => c.id === selectedClass)?.level || ""}
                      date={format(selectedDate, "yyyy-MM-dd")} 
                      students={classStudents}
                    />
                  ) : (
                    <div className="text-center py-8 border rounded-lg">
                      <User className="mx-auto h-8 w-8 text-muted-foreground" />
                      <h3 className="mt-2 text-sm font-medium">No students in this class</h3>
                      <p className="mt-1 text-sm text-muted-foreground">
                        Add students to this class first
                      </p>
                    </div>
                  )
                ) : (
                  <div className="flex items-center justify-center py-8">
                    <Loader2 className="h-6 w-6 animate-spin mr-2" />
                    <p>Select a class to continue</p>
                  </div>
                )}
              </CardContent>
            </Card>
          </TabsContent>
          
          {/* <TabsContent value="view" className="space-y-6">
            <TooltipProvider>
              {selectedStudent ? (
                <Card>
                  <CardHeader>
                    <CardTitle className="flex items-center">
                      <CalendarCheck className="mr-2 h-5 w-5" />
                      Attendance Record for {selectedStudent.firstName} {selectedStudent.lastName}
                    </CardTitle>
                    <CardDescription>
                      View and analyze attendance data for this student
                    </CardDescription>
                  </CardHeader>
                  <CardContent>
                    {isLoading ? (
                      <div className="space-y-4">
                        <div className="grid grid-cols-1 md:grid-cols-3 gap-4">
                          {[...Array(3)].map((_, i) => (
                            <Skeleton key={i} className="h-24 rounded-lg" />
                          ))}
                        </div>
                        <Skeleton className="h-64 w-full rounded-lg" />
                      </div>
                    ) : (
                      <>
                        <div className="grid grid-cols-1 md:grid-cols-3 gap-4 mb-6">
                          <StatCard 
                            value={studentStats.present}
                            label="Days Present"
                            variant="success"
                          />
                          <StatCard 
                            value={studentStats.absent}
                            label="Days Absent"
                            variant="destructive"
                          />
                          <StatCard 
                            value={studentStats.late}
                            label="Days Late"
                            variant="warning"
                          />
                        </div>
                        
                        <div className="rounded-md border">
                          <div className="p-4 border-b">
                            <h3 className="font-medium">Recent Attendance Records</h3>
                          </div>
                          {studentAttendance.length === 0 ? (
                            <div className="p-4 text-center text-muted-foreground">
                              No attendance records found for this student
                            </div>
                          ) : (
                            <Table>
                              <TableHeader>
                                <TableRow>
                                  <TableHead>Date</TableHead>
                                  <TableHead>Status</TableHead>
                                  <TableHead>Marked By</TableHead>
                                  <TableHead>Remarks</TableHead>
                                </TableRow>
                              </TableHeader>
                              <TableBody>
                                {studentAttendance.slice(0, 10).map((record) => (
                                  <TableRow key={record.id}>
                                    <TableCell>
                                      {new Date(record.date).toLocaleDateString('en-US', {
                                        weekday: 'short',
                                        year: 'numeric',
                                        month: 'short',
                                        day: 'numeric'
                                      })}
                                    </TableCell>
                                    <TableCell>
                                      <StatusBadge 
                                        status={record.status} 
                                        remarks={record.remarks}
                                      />
                                    </TableCell>
                                    <TableCell>
                                      <div className="flex items-center gap-2">
                                        <span className="flex items-center">
                                          <User className="h-4 w-4 mr-1 text-muted-foreground" />
                                          {typeof record.markedBy === 'string' 
                                            ? record.markedBy 
                                            : `${record.markedBy.name}`
                                          }
                                        </span>
                                        {typeof record.markedBy !== 'string' && (
                                          <span className="text-xs text-muted-foreground">
                                            {new Date(record.markedBy.timestamp).toLocaleTimeString()}
                                          </span>
                                        )}
                                      </div>
                                    </TableCell>
                                    <TableCell>
                                      {record.remarks ? (
                                        <Tooltip>
                                          <TooltipTrigger asChild>
                                            <p className="line-clamp-1 text-left">
                                              {record.remarks}
                                            </p>
                                          </TooltipTrigger>
                                          <TooltipContent className="max-w-[300px]">
                                            <p>{record.remarks}</p>
                                          </TooltipContent>
                                        </Tooltip>
                                      ) : (
                                        <span className="text-muted-foreground">-</span>
                                      )}
                                    </TableCell>
                                  </TableRow>
                                ))}
                              </TableBody>
                            </Table>
                          )}
                        </div>
                      </>
                    )}
                  </CardContent>
                </Card>
              ) : (
                <Card>
                  <CardHeader>
                    <CardTitle>{isWeekdayView ? 'Weekday' : 'Saturday'} Attendance Overview</CardTitle>
                    <CardDescription>
                      View attendance statistics for {isWeekdayView ? 'weekdays (Monday-Friday)' : 'Saturdays'}
                    </CardDescription>
                  </CardHeader>
                  <CardContent className="space-y-6">
                    <div>
                      <label className="block text-sm font-medium mb-2">Select Class</label>
                      {classesLoading ? (
                        <Skeleton className="h-10 w-full" />
                      ) : (
                        <Select
                          value={selectedClass}
                          onValueChange={setSelectedClass}
                          disabled={classesLoading || classes.length === 0}
                        >
                          <SelectTrigger className="w-full [&>svg]:transition-transform [&[data-state=open]>svg]:rotate-180">
                            <SelectValue placeholder={classesLoading ? "Loading classes..." : "Select a class"} />
                          </SelectTrigger>
                          <SelectContent>
                            {classes.map((cls) => (
                              <SelectItem key={cls.id} value={cls.id}>
                                {cls.name}
                              </SelectItem>
                            ))}
                          </SelectContent>
                        </Select>
                      )}
                    </div>
                    
                    {isLoading ? (
                      <Skeleton className="h-80 w-full rounded-lg" />
                    ) : (
                      <>
                        <ChartContainer
                          title={`${isWeekdayView ? 'Weekday' : 'Saturday'} Attendance Overview`}
                          description={`Attendance statistics for ${isWeekdayView ? 'weekdays' : 'Saturdays'}`}
                          type="bar"
                          data={weeklyAttendance}
                        />
                        
                        <div className="pt-4">
                          <h4 className="font-medium mb-3">Recent Records</h4>
                          <div className="border rounded-lg">
                            <Table>
                              <TableHeader>
                                <TableRow>
                                  <TableHead>Date</TableHead>
                                  <TableHead>Present</TableHead>
                                  <TableHead>Absent</TableHead>
                                  <TableHead>Late</TableHead>
                                  <TableHead>Remarks</TableHead>
                                </TableRow>
                              </TableHeader>
                              <TableBody>
                                {weeklyAttendance.slice(0, 5).map((day, index) => (
                                  <TableRow key={index}>
                                    <TableCell>{day.name}</TableCell>
                                    <TableCell className="text-green-600">{day.present}</TableCell>
                                    <TableCell className="text-red-600">{day.absent}</TableCell>
                                    <TableCell className="text-yellow-600">{day.late}</TableCell>
                                    <TableCell>
                                      <Tooltip>
                                        <TooltipTrigger asChild>
                                          <Info className="h-4 w-4 text-muted-foreground" />
                                        </TooltipTrigger>
                                        <TooltipContent>
                                          <p>View detailed records for this day</p>
                                        </TooltipContent>
                                      </Tooltip>
                                    </TableCell>
                                  </TableRow>
                                ))}
                              </TableBody>
                            </Table>
                          </div>
                        </div>
                      </>
                    )}
                  </CardContent>
                </Card>
              )}
            </TooltipProvider>
          </TabsContent> */}
          <TabsContent value="view" className="space-y-6">
            <TooltipProvider>
              {selectedStudent ? (
                <Card key={`student-${selectedStudent.id}`}>
                  <CardHeader>
                    <CardTitle className="flex items-center">
                      <CalendarCheck className="mr-2 h-5 w-5" />
                      Attendance Record for {selectedStudent.firstName} {selectedStudent.lastName}
                    </CardTitle>
                    <CardDescription>
                      View and analyze attendance data for this student
                    </CardDescription>
                  </CardHeader>
                  <CardContent>
                    {isLoading ? (
                      <div className="space-y-4">
                        <div className="grid grid-cols-1 md:grid-cols-3 gap-4">
                          {[...Array(3)].map((_, i) => (
                            <Skeleton key={i} className="h-24 rounded-lg" />
                          ))}
                        </div>
                        <Skeleton className="h-64 w-full rounded-lg" />
                      </div>
                    ) : (
                      <>
                        <div className="grid grid-cols-1 md:grid-cols-3 gap-4 mb-6">
                          <StatCard 
                            value={studentStats.present}
                            label="Days Present"
                            variant="success"
                          />
                          <StatCard 
                            value={studentStats.absent}
                            label="Days Absent"
                            variant="destructive"
                          />
                          <StatCard 
                            value={studentStats.late}
                            label="Days Late"
                            variant="warning"
                          />
                        </div>
                        
                        <div className="rounded-md border">
                          <div className="p-4 border-b">
                            <h3 className="font-medium">Recent Attendance Records</h3>
                          </div>
                          {studentAttendance.length === 0 ? (
                            <div className="p-4 text-center text-muted-foreground">
                              No attendance records found for this student
                            </div>
                          ) : (
                            <Table>
                              <TableHeader>
                                <TableRow>
                                  <TableHead>Date</TableHead>
                                  <TableHead>Status</TableHead>
                                  <TableHead>Class</TableHead>
                                  <TableHead>Marked By</TableHead>
                                  <TableHead>Remarks</TableHead>
                                </TableRow>
                              </TableHeader>
                              <TableBody>
                                {studentAttendance.slice(0, 10).map((record) => (
                                  <TableRow key={record.id}>
                                    <TableCell>
                                      {new Date(record.date).toLocaleDateString('en-GB', {
                                        weekday: 'short',
                                        year: 'numeric',
                                        month: 'short',
                                        day: 'numeric'
                                      })}
                                    </TableCell>
                                    <TableCell>
                                      <StatusBadge 
                                        status={record.status} 
                                        remarks={record.remarks}
                                      />
                                    </TableCell>
                                    <TableCell>{record.className} {record.classLevel && `(${record.classLevel})`}</TableCell>
                                    <TableCell>
                                      <div className="flex items-center gap-2">
                                        <span className="flex items-center">
                                          <User className="h-4 w-4 mr-1 text-muted-foreground" />
                                          {typeof record.markedBy === 'string' 
                                            ? record.markedBy 
                                            : `${record.markedBy.name}`
                                          }
                                        </span>
                                        {typeof record.markedBy !== 'string' && (
                                          <span className="text-xs text-muted-foreground">
                                            {new Date(record.markedBy.timestamp).toLocaleTimeString()}
                                          </span>
                                        )}
                                      </div>
                                    </TableCell>
                                    <TableCell>
                                      {record.remarks ? (
                                        <Tooltip>
                                          <TooltipTrigger asChild>
                                            <p className="line-clamp-1 text-left">
                                              {record.remarks}
                                            </p>
                                          </TooltipTrigger>
                                          <TooltipContent className="max-w-[300px]">
                                            <p>{record.remarks}</p>
                                          </TooltipContent>
                                        </Tooltip>
                                      ) : (
                                        <span className="text-muted-foreground">-</span>
                                      )}
                                    </TableCell>
                                  </TableRow>
                                ))}
                              </TableBody>
                            </Table>
                          )}
                        </div>
                      </>
                    )}
                  </CardContent>
                </Card>
              ) : (
                <Card>
                  <CardHeader>
                    <CardTitle>{isWeekdayView ? 'Weekday' : 'Saturday'} Attendance Overview</CardTitle>
                    <CardDescription>
                      View attendance statistics for {isWeekdayView ? 'weekdays (Monday-Friday)' : 'Saturdays'}
                    </CardDescription>
                  </CardHeader>
                  <CardContent className="space-y-6">
                    <div>
                      <label className="block text-sm font-medium mb-2">Select Class</label>
                      {classesLoading ? (
                        <Skeleton className="h-10 w-full" />
                      ) : (
                        <Select
                          value={selectedClass}
                          onValueChange={setSelectedClass}
                          disabled={classesLoading || classes.length === 0}
                        >
                          <SelectTrigger className="w-full [&>svg]:transition-transform [&[data-state=open]>svg]:rotate-180">
                            <SelectValue placeholder={classesLoading ? "Loading classes..." : "Select a class"} />
                          </SelectTrigger>
                          <SelectContent>
                            {classes.map((cls) => (
                              <SelectItem key={cls.id} value={cls.id}>
                                {cls.level ? `${cls.name} (${cls.level})` : cls.name}
                              </SelectItem>
                            ))}
                          </SelectContent>
                        </Select>
                      )}
                    </div>
                    
                    {isLoading ? (
                      <Skeleton className="h-80 w-full rounded-lg" />
                    ) : (
                      <>
                        <ChartContainer
                          title={`${isWeekdayView ? 'Weekday' : 'Saturday'} Attendance Overview`}
                          description={`Attendance statistics for ${isWeekdayView ? 'weekdays' : 'Saturdays'}`}
                          type="bar"
                          data={weeklyAttendance}
                          dataKeys={{
                            value: 'present',
                            value2: 'absent',
                            value3: 'late',
                            name: 'name'
                          }}
                          legendNames={{
                            value: 'Present',
                            value2: 'Absent',
                            value3: 'Late'
                          }}
                        />
                        
                        <div className="pt-4">
                          <h4 className="font-medium mb-3">Recent Records</h4>
                          <div className="border rounded-lg">
                            <Table>
                              <TableHeader>
                                <TableRow>
                                  <TableHead>Date</TableHead>
                                  <TableHead>Present</TableHead>
                                  <TableHead>Absent</TableHead>
                                  <TableHead>Late</TableHead>
                                  <TableHead>Remarks</TableHead>
                                </TableRow>
                              </TableHeader>
                              <TableBody>
                                {weeklyAttendance.slice(0, 5).map((day, index) => (
                                  <TableRow key={index}>
                                    <TableCell>{day.name}</TableCell>
                                    <TableCell className="text-green-600">{day.present}</TableCell>
                                    <TableCell className="text-red-600">{day.absent}</TableCell>
                                    <TableCell className="text-yellow-600">{day.late}</TableCell>
                                    <TableCell>
                                      <Tooltip>
                                        <TooltipTrigger asChild>
                                          <Info className="h-4 w-4 text-muted-foreground" />
                                        </TooltipTrigger>
                                        <TooltipContent>
                                          <p>View detailed records for this day</p>
                                        </TooltipContent>
                                      </Tooltip>
                                    </TableCell>
                                  </TableRow>
                                ))}
                              </TableBody>
                            </Table>
                          </div>
                        </div>
                      </>
                    )}
                  </CardContent>
                </Card>
              )}
            </TooltipProvider>
          </TabsContent>
        </Tabs>
      </div>
    </DashboardLayout>
  );
}